import LRU from 'lru-cache';
import { syncMemoizer } from './sync';
export declare type LoadFunction<TPar1, TPar2, TPar3, TCallback> = ((callback: TCallback) => void) | ((arg: TPar1, callback: TCallback) => void) | ((arg1: TPar1, arg2: TPar2, callback: TCallback) => void) | ((arg1: TPar1, arg2: TPar2, arg3: TPar3, callback: TCallback) => void);
export interface AsyncParams1<TPar1, TPar2, TPar3, TCallback> extends LRU.Options<string, any> {
    /**
     * The function that loads the resource when is not in the cache.
     */
    load: LoadFunction<TPar1, TPar2, TPar3, TCallback>;
    /**
     * A function to generate the key of the cache.
     */
    hash: (arg1?: TPar1, arg2?: TPar2, arg3?: TPar3) => string;
    /**
     * Return true if the result should not be retrieved from the cache.
     */
    bypass?: (arg1?: TPar1, arg2?: TPar2, arg3?: TPar3) => boolean;
    /**
     * An optional function to indicate the maxAge of an specific item.
     */
    itemMaxAge: ((...results: any[]) => number) | ((arg: TPar1, ...results: any[]) => number) | ((arg1: TPar1, arg2: TPar2, ...results: any[]) => number) | ((arg1: TPar1, arg2: TPar2, arg3: TPar3, ...results: any[]) => number);
    /**
     * Indicates if the resource should be freezed.
     */
    freeze?: boolean;
    /**
     * Indicates if the resource should be cloned before is returned.
     */
    clone?: boolean;
    /**
     * Disable the cache and executes the load logic directly.
     */
    disable?: boolean;
}
declare function asyncMemoizer<TPar1, TPar2, TPar3, TCallback>(options: AsyncParams1<TPar1, TPar2, TPar3, TCallback>): LoadFunction<TPar1, TPar2, TPar3, TCallback>;
declare namespace asyncMemoizer {
    var sync: typeof syncMemoizer;
}
export { asyncMemoizer };
