import LRU from 'lru-cache';
export declare type SyncLoadFunction<TPar1, TPar2, TPar3, TResult> = (() => TResult) | ((arg: TPar1) => TResult) | ((arg1: TPar1, arg2: TPar2) => TResult) | ((arg1: TPar1, arg2: TPar2, arg3: TPar3) => TResult);
export interface SyncParams<TPar1, TPar2, TPar3, TResult> extends LRU.Options<string, any> {
    /**
     * The function that loads the resource when is not in the cache.
     */
    load: SyncLoadFunction<TPar1, TPar2, TPar3, TResult>;
    /**
     * A function to generate the key of the cache.
     */
    hash: (arg1?: TPar1, arg2?: TPar2, arg3?: TPar3) => string;
    /**
     * Return true if the result should not be retrieved from the cache.
     */
    bypass?: (arg1?: TPar1, arg2?: TPar2, arg3?: TPar3) => boolean;
    /**
     * An optional function to indicate the maxAge of an specific item.
     */
    itemMaxAge: ((result: TResult) => number) | ((arg: TPar1, result: TResult) => number) | ((arg1: TPar1, arg2: TPar2, result: TResult) => number) | ((arg1: TPar1, arg2: TPar2, arg3: TPar3, result: TResult) => number);
    /**
     * Indicates if the resource should be freezed.
     */
    freeze?: boolean;
    /**
     * Indicates if the resource should be cloned before is returned.
     */
    clone?: boolean;
    /**
     * Disable the cache and executes the load logic directly.
     */
    disable?: boolean;
}
export declare function syncMemoizer<TPar1, TPar2, TPar3, TResult>(options: SyncParams<TPar1, TPar2, TPar3, TResult>): SyncLoadFunction<TPar1, TPar2, TPar3, TResult>;
